require './mkmf2'

setup_dir '.', "CTioga"
declare_exec("bin/ctioga")
declare_exec("bin/ctable")

setup_dir 'Backends', "SciYAG"

setup_dir('MetaBuilder', 'MetaBuilder')

write_makefile

